MCD inheritance_weak
CONTRAT ( #num prof, date contrat, salaire horaire contrat )

- Le champ num prof fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré à partir de l'entité VACATAIRE pour renforcer l'identifiant.
- Le champ date contrat fait partie de la clé primaire de la table. C'était déjà un identifiant de l'entité CONTRAT.
- Le champ salaire horaire contrat était déjà un simple attribut de l'entité CONTRAT.

SALARIÉ ( num prof, nom prof, prénom prof, téléphone prof, date embauche salarié, échelon salarié, salaire salarié )

- Le champ num prof constitue la clé primaire de la table. Il était clé primaire de l'entité-mère PROFESSEUR (supprimée).
- Le champ nom prof est un simple attribut. Il était simple attribut de l'entité-mère PROFESSEUR (supprimée).
- Le champ prénom prof est un simple attribut. Il était simple attribut de l'entité-mère PROFESSEUR (supprimée).
- Le champ téléphone prof est un simple attribut. Il était simple attribut de l'entité-mère PROFESSEUR (supprimée).
- Les champs date embauche salarié, échelon salarié et salaire salarié étaient déjà de simples attributs de l'entité SALARIÉ.

VACATAIRE ( num prof, nom prof, prénom prof, téléphone prof, statut vacataire )

- Le champ num prof constitue la clé primaire de la table. Il était clé primaire de l'entité-mère PROFESSEUR (supprimée).
- Le champ nom prof est un simple attribut. Il était simple attribut de l'entité-mère PROFESSEUR (supprimée).
- Le champ prénom prof est un simple attribut. Il était simple attribut de l'entité-mère PROFESSEUR (supprimée).
- Le champ téléphone prof est un simple attribut. Il était simple attribut de l'entité-mère PROFESSEUR (supprimée).
- Le champ statut vacataire était déjà un simple attribut de l'entité VACATAIRE.